Changelog
=========

0.1.7 (2017-02-21)
------------------

- Use enclosure media type for lead image.
  [bsuttor]


0.1.6 (2016-11-16)
------------------

- Fix event rss.
  [bsuttor]


0.1.5 (2016-04-25)
------------------

- Add dexterity support.
  [bsuttor]

- Lint README file
  [bsuttor]


0.1.4 (2015-05-12)
------------------

- Modifications to get events' startdate and enddate into RSS feeds.
  [cboulanger]


0.1.2 (2015-03-12)
------------------

- Do use override.zcml, for settings adapter.
  [bsuttor]


0.1 (2015-03-05)
----------------

- Package created using mr.bob
  [bsuttor]
